@@ -7,7 +7,7 @@ from .common import execute
 def main():
     argv = sys.argv[1:]
     begin = time.monotonic()
-    execute(argv)
+    execute(" ".join(argv))
     end = time.monotonic()
     print(f"Exited in {end - begin}s")
     sys.exit()
